
> module ComposersWorkbenchTests where

> import ComposersWorkbench
> import Testing

************
* Tests
************

Unit Tests...

> allTests :: [IO ()]
> allTests = [quickCheck prop_Transpose, 
>             quickCheck prop_invertPCS, 
>             quickCheck prop_maxInterval,
>             quickCheck prop_normalForm,
>             quickCheck prop_normalForm2,
>             quickCheck prop_scanAcc,
>             quickCheck prop_primeForm1,
>             quickCheck prop_primeForm2,
>             quickCheck prop_primeForm3,
>             quickCheck prop_listComb1,
>             quickCheck prop_listComb2,
>             quickCheck prop_listComb3,
>             quickCheck prop_listComb4,
>             quickCheck prop_intervalVector,
>             quickCheck prop_mostPacked,
>             quickCheck prop_subtractPCS]

> test :: IO [()]
> test = runTests "Sandbox 1" allTests

> prop_Transpose = transpose (-3) [0, 3, 11, 5, 4] == [9, 0, 8, 2, 1]
> prop_invertPCS = invertPCS [0, 2, 4, 11, 7] == [0, 10, 8, 1, 5]
> prop_maxInterval = maxInterval [4, 3, 11, 9] == 8
> prop_normalForm = normalForm0 [4,0,8,6] == [0, 2, 4, 8]
> prop_normalForm2 = normalForm0 [6,8,0,4] == [0, 2, 4, 8]
> prop_scanAcc = scanAcc (1:) 3 [0] == [[1, 0], [1, 1, 0], [1, 1, 1, 0]]
> prop_primeForm1 = primeForm [6,8,0,4] == [0, 2, 4, 8]
> prop_primeForm2 = primeForm [2,4,8,9] == [0,1,5,7] 
> prop_primeForm3 = primeForm [0,2,4,7,8,11] == [0,1,3,5,8,9] 
> prop_listComb1 aList = listCompProp 1 0 aList
> prop_listComb2 aList = listCompProp 2 1 aList
> prop_listComb3 aList = listCompProp 3 3 aList
> prop_listComb4 aList = listCompProp 4 6 aList

> listCompProp inL expL aList 
>   = assertLength inL aList ==> assertLength expL (listCombinations aList) 
>   where types = aList :: [Int] 
> assertLength expected aList = (length aList) == expected

> prop_intervalVector = (intervalVector2List $ intervalVector [0, 2, 7, 8]) == [1,1,0,1,2,1]
> prop_mostPacked = mostPacked [0,2,4,8] [0,4,6,8] == [0,2,4,8]
> prop_subtractPCS = (subtractPCS [even x | x <- [0..]] [0,2,7,4,3,3,1]) == [0,7,3,1]

Smoke Tests ...

> subtractMTest = subtractM [even x | x <- [1,1,0,0,1,1,1]] maryMusic

> noteDensityTest = noteDensity maryMusic
> noteDensityTest2 = noteDensity (Tempo 7 maryMusic)

> cycleInTest = cycleIn True [0, 7, 13, 18] -- should be [0, 18, 7, 13]

[0,1,4]; [3,4,7]; [0,3,4]; [5,8,9]; and [8,9,0]  all belong to the Prime Form:  (0,1,4)
can you hear that these are all of the same prime form?

> pf014Music = foldr (:+:) emptyMusic (map pcs2Chord [[0, 1, 4], [3,4,7], [0,3,4], [5,8,9], [8,9,0]])
> playPF014Music = testMac pf014Music "pf014Music"

> cycleTestInM :: Music
> cycleTestInM = Tempo 30 (pcs2Melody pitches) where
>   pitches = foldr (++) [] (replicate 16 core)
>   core    = cycleInTest ++ (cycleIn False [0,7,13,18])

> playCycleTestMusic = testMac cycleTestInM "cycleTest"

> allRotationsTest1 = allRotations [0,4,7]
> allRotationsTest2 = allRotations [0,4,6,8]

Mary Had a Little Lamb -- the musician's "Hello World"

> maryMusic :: Music
> maryMusic = melody where
>   melody = note1 :+: note2 :+: note3 :+: note2 :+: note1 :+: note1 :+: note1
>   note1  = e oct qn []
>   note2  = d oct qn []
>   note3  = c oct qn []
>   oct    = 5 

> playMaryMusic :: IO ()
> playMaryMusic = testMac maryMusic "maryMusic"

> playM37 :: IO ()
> playM37 = testMac mikrokosmos37 "mikrokosmos37"

I'm not sure if this code belongs here...

> module Testing (module Testing, module QuickCheck) where

A simple extension to QuickCheck to allow batching of tests without having to run a cmdline script, or inspect source code...

> import QuickCheck

> runTests :: String -> [IO ()] -> IO [()]
> runTests moduleName tests 
>   = do putStrLn ("Tests For Module \""++ moduleName ++ "\"")
>        putStrLn "==================================="
>        sequence output where
>   output        = map printTestCase allTestCases
>   printTestCase (label, testCase) = putStr label >> testCase
>   allTestCases = (take (length tests) (zip labels tests))
>   labels       = (map (\num -> (show num) ++ ") ") [1..]) 


